from .ekonf import eKonf
from .base import __hydra_version_base__
from . import _version

__version__ = _version.get_versions()["version"]
